==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectJacobian.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectjacobian_h
#define objectjacobian_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
typedef enum {
  adms_jacobian_enumeration_diagonal_no,
  adms_jacobian_enumeration_diagonal_yes
} e_jacobian_diagonal;
win32_interface char* adms_jacobian_tostring_diagonal_impl (p_admsttransform myadmsttransform,e_jacobian_diagonal e);
win32_interface e_jacobian_diagonal adms_jacobian_fromstring_diagonal_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_jacobian_enumeration_dynamic_no,
  adms_jacobian_enumeration_dynamic_yes
} e_jacobian_dynamic;
win32_interface char* adms_jacobian_tostring_dynamic_impl (p_admsttransform myadmsttransform,e_jacobian_dynamic e);
win32_interface e_jacobian_dynamic adms_jacobian_fromstring_dynamic_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_jacobian_enumeration_static_no,
  adms_jacobian_enumeration_static_yes
} e_jacobian_static;
win32_interface char* adms_jacobian_tostring_static_impl (p_admsttransform myadmsttransform,e_jacobian_static e);
win32_interface e_jacobian_static adms_jacobian_fromstring_static_impl (p_admsttransform myadmsttransform,char*token);
struct s_jacobian {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_node _row;
  int _row_isdefault : 1;
  p_node _column;
  int _column_isdefault : 1;
  e_jacobian_diagonal _diagonal;
  int _diagonal_isdefault : 1;
  e_jacobian_dynamic _dynamic;
  int _dynamic_isdefault : 1;
  e_jacobian_static _static;
  int _static_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectNode.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_jacobian_getuid (p_jacobian myjacobian);
win32_interface gboolean adms_jacobian_cmp (p_jacobian myjacobian,p_jacobian refjacobian);
win32_interface p_jacobian adms_jacobian_new_1 (p_module mymodule,p_node myrow,p_node mycolumn);
#define adms_jacobian_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_jacobian_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_jacobian_new_impl (p_adms arguments[]);
win32_interface p_jacobian adms_jacobian_impl (void* member);
#define adms_jacobian(member) ((p_jacobian) (member))
#define adms_jacobian_new adms_jacobian_new_1
#define adms_jacobian_isdefault_module(jacobian) (adms_jacobian(jacobian)->_module_isdefault)
#define adms_jacobian_valueof_module(jacobian) (adms_jacobian(jacobian)->_module)
#define adms_jacobian_isdefault_row(jacobian) (adms_jacobian(jacobian)->_row_isdefault)
#define adms_jacobian_valueof_row(jacobian) (adms_jacobian(jacobian)->_row)
#define adms_jacobian_isdefault_column(jacobian) (adms_jacobian(jacobian)->_column_isdefault)
#define adms_jacobian_valueof_column(jacobian) (adms_jacobian(jacobian)->_column)
#define adms_jacobian_isdefault_diagonal(jacobian) (adms_jacobian(jacobian)->_diagonal_isdefault)
#define adms_jacobian_valueof_diagonal(jacobian) (adms_jacobian(jacobian)->_diagonal)
#define adms_jacobian_isdefault_dynamic(jacobian) (adms_jacobian(jacobian)->_dynamic_isdefault)
#define adms_jacobian_valueof_dynamic(jacobian) (adms_jacobian(jacobian)->_dynamic)
#define adms_jacobian_isdefault_static(jacobian) (adms_jacobian(jacobian)->_static_isdefault)
#define adms_jacobian_valueof_static(jacobian) (adms_jacobian(jacobian)->_static)
#define adms_jacobian_valueof_adms(jacobian) ((p_adms)jacobian)
#define adms_jacobian_valueto_module(a,b) ((p_jacobian)a)->_module=(b)
win32_interface void adms_jacobian_valueto_module_impl (p_jacobian myjacobian,p_module _module);
#define adms_jacobian_valueto_row(a,b) ((p_jacobian)a)->_row=(b)
win32_interface void adms_jacobian_valueto_row_impl (p_jacobian myjacobian,p_node _row);
#define adms_jacobian_valueto_column(a,b) ((p_jacobian)a)->_column=(b)
win32_interface void adms_jacobian_valueto_column_impl (p_jacobian myjacobian,p_node _column);
#define adms_jacobian_valueto_diagonal(a,b) ((p_jacobian)a)->_diagonal=(b)
win32_interface void adms_jacobian_valueto_diagonal_impl (p_jacobian myjacobian,e_jacobian_diagonal _diagonal);
#define adms_jacobian_valueto_dynamic(a,b) ((p_jacobian)a)->_dynamic=(b)
win32_interface void adms_jacobian_valueto_dynamic_impl (p_jacobian myjacobian,e_jacobian_dynamic _dynamic);
#define adms_jacobian_valueto_static(a,b) ((p_jacobian)a)->_static=(b)
win32_interface void adms_jacobian_valueto_static_impl (p_jacobian myjacobian,e_jacobian_static _static);
#endif /* objectjacobian_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectJacobian.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectjacobian_h
#define objectjacobian_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
typedef enum {
  adms_jacobian_enumeration_diagonal_no,
  adms_jacobian_enumeration_diagonal_yes
} e_jacobian_diagonal;
win32_interface char* adms_jacobian_tostring_diagonal_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_jacobian_diagonal adms_jacobian_fromstring_diagonal_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_jacobian_enumeration_static_no,
  adms_jacobian_enumeration_static_yes
} e_jacobian_static;
win32_interface char* adms_jacobian_tostring_static_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_jacobian_static adms_jacobian_fromstring_static_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_jacobian_enumeration_dynamic_no,
  adms_jacobian_enumeration_dynamic_yes
} e_jacobian_dynamic;
win32_interface char* adms_jacobian_tostring_dynamic_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_jacobian_dynamic adms_jacobian_fromstring_dynamic_impl (p_admsttransform myadmsttransform,char*token);
struct s_jacobian {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_node _row;
  int _row_isdefault : 1;
  p_node _column;
  int _column_isdefault : 1;
  p_enumeration _diagonal;
  int _diagonal_isdefault : 1;
  p_enumeration _static;
  int _static_isdefault : 1;
  p_enumeration _dynamic;
  int _dynamic_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectNode.h>
#include <admsObject/objectEnumeration.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_jacobian_uid (p_jacobian myjacobian);
win32_interface int adms_jacobian_cmp (p_jacobian myjacobian,p_jacobian refjacobian);
win32_interface p_jacobian adms_jacobian_new(p_module mymodule,p_node myrow,p_node mycolumn);
win32_interface p_adms adms_jacobian_new_impl (p_adms arguments[]);
#define adms_jacobian(member) ((p_jacobian) (member))
#define adms_jacobian_isdefault_module(jacobian) (adms_jacobian(jacobian)->_module_isdefault)
#define adms_jacobian_valueof_module(jacobian) (adms_jacobian(jacobian)->_module)
#define adms_jacobian_isdefault_row(jacobian) (adms_jacobian(jacobian)->_row_isdefault)
#define adms_jacobian_valueof_row(jacobian) (adms_jacobian(jacobian)->_row)
#define adms_jacobian_isdefault_column(jacobian) (adms_jacobian(jacobian)->_column_isdefault)
#define adms_jacobian_valueof_column(jacobian) (adms_jacobian(jacobian)->_column)
#define adms_jacobian_isdefault_diagonal(jacobian) (adms_jacobian(jacobian)->_diagonal_isdefault)
#define adms_jacobian_valueof_diagonal(jacobian) (adms_jacobian(jacobian)->_diagonal)
#define adms_jacobian_isdefault_static(jacobian) (adms_jacobian(jacobian)->_static_isdefault)
#define adms_jacobian_valueof_static(jacobian) (adms_jacobian(jacobian)->_static)
#define adms_jacobian_isdefault_dynamic(jacobian) (adms_jacobian(jacobian)->_dynamic_isdefault)
#define adms_jacobian_valueof_dynamic(jacobian) (adms_jacobian(jacobian)->_dynamic)
#define adms_jacobian_valueof_adms(jacobian) ((p_adms)jacobian)
win32_interface inline void adms_jacobian_valueto_module (p_jacobian myjacobian,p_module _module);
win32_interface inline void adms_jacobian_valueto_row (p_jacobian myjacobian,p_node _row);
win32_interface inline void adms_jacobian_valueto_column (p_jacobian myjacobian,p_node _column);
win32_interface inline void adms_jacobian_valueto_diagonal (p_jacobian myjacobian,p_enumeration _diagonal);
win32_interface inline void adms_jacobian_valueto_static (p_jacobian myjacobian,p_enumeration _static);
win32_interface inline void adms_jacobian_valueto_dynamic (p_jacobian myjacobian,p_enumeration _dynamic);
win32_interface inline void adms_jacobian_free(p_jacobian myjacobian);
#endif /* objectjacobian_h */
